@@ -1424,7 +1424,7 @@ sunone_connection_createcalendar (SunOneConnection *connection, const gchar *cal
 			SunOneCalendarSubscription *sub;
 
 			sub = g_new0 (SunOneCalendarSubscription, 1);
-			sub->calid = g_strdup_printf (calidtmp);
+			sub->calid = g_strdup (calidtmp);
 			sub->display_name = g_strdup (calid);
 
 			prefs->subscriptions = g_list_append (prefs->subscriptions, sub);
